#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_GENMASK_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_GENMASK_HPP_INCLUDED

#include <nt2/bitwise/include/functions/scalar/genmask.hpp>

#endif
